Module pass

Module pass 

Public API for pass. Pass infrastructure: FunctionPass, ModulePass, and PassManager.

A FunctionPass transforms a single Function in isolation. A ModulePass transforms the whole Module (needed for inter-procedural passes such as inlining).

PassManager sequences module passes and runs them to a fixed point.

Structs

FunctionPassAdapter
Applies a FunctionPass to every non-declaration function in the module.
PassManager
Sequences module passes and runs them once, or to a fixed point.

Traits

FunctionPass
A pass that transforms a single function.
ModulePass
A pass that transforms an entire module.