Public API for dce.
Dead-code elimination (DCE).
Removes instructions whose results are never used and which have no
observable side effects. A single scan is enough; iterate via the
PassManager for a full fixed-point.
Side-effecting instructions (Store, Call, Load, Alloca,
terminators) are never removed even if their results are unused.
Structs
- Dead
Code Elim - Dead-code elimination pass.
Functions
- is_
dce_ safe - Returns
trueif an unused instruction with this kind can safely be deleted.