pub struct Ipcp;Expand description
Simple IPCP pass:
- detect a direct callee argument that is constant across all direct callsites
- clone callee and substitute that argument with the constant
- redirect matching callsites to the specialized clone