Public API for pass.
Pass infrastructure: FunctionPass, ModulePass, and PassManager.
A FunctionPass transforms a single Function in isolation.
A ModulePass transforms the whole Module (needed for inter-procedural
passes such as inlining).
PassManager sequences module passes and runs them to a fixed point.
Structs
- Function
Pass Adapter - Applies a
FunctionPassto every non-declaration function in the module. - Pass
Manager - Sequences module passes and runs them once, or to a fixed point.
Traits
- Function
Pass - A pass that transforms a single function.
- Module
Pass - A pass that transforms an entire module.